@@ -1442,11 +1442,11 @@ class WeeklyReportDialog:
         
         ttk.Label(main_frame, text="Please reflect on your week using the template below:", font=("Arial", 9)).grid(row=5, column=0, columnspan=2, sticky=tk.W, pady=(0, 5))
         
-        # Reflection text area
+        # Reflection text area - make it bigger
         reflection_frame = ttk.Frame(main_frame)
         reflection_frame.grid(row=6, column=0, columnspan=2, sticky=(tk.W, tk.E, tk.N, tk.S), pady=(0, 10))
         
-        self.reflection_text = tk.Text(reflection_frame, height=8, width=70, wrap=tk.WORD)
+        self.reflection_text = tk.Text(reflection_frame, height=12, width=80, wrap=tk.WORD)
         scrollbar = ttk.Scrollbar(reflection_frame, orient=tk.VERTICAL, command=self.reflection_text.yview)
         self.reflection_text.configure(yscrollcommand=scrollbar.set)
         
@@ -1538,18 +1538,26 @@ class WeeklyReportDialog:
             # Generate timesheet content
             timesheet_content = self.generate_timesheet_content(weekly_entries)
             
-            # Combine timesheet and reflection
-            email_body = f"""Dear Professor,
-
-Please find attached my weekly timesheet for the week of {start_of_week.strftime('%B %d, %Y')}.
-
-{timesheet_content}
-
-WEEKLY REFLECTION:
-{reflection_content}
-
-Best regards,
-Student"""
+            # Generate HTML formatted email
+            html_timesheet = self.generate_html_timesheet(weekly_entries)
+            
+            # Combine timesheet and reflection in HTML format
+            email_body = f"""
+            <div style='font-family: Arial, sans-serif; line-height: 1.6; color: #333;'>
+                <p>Dear Professor,</p>
+                
+                <p>Please find attached my weekly timesheet for the week of {start_of_week.strftime('%B %d, %Y')}.</p>
+                
+                {html_timesheet}
+                
+                <div style='margin-top: 30px; padding: 20px; background-color: #f8f9fa; border-left: 4px solid #3498db;'>
+                    <h3 style='color: #2c3e50; margin-top: 0; margin-bottom: 15px;'>WEEKLY REFLECTION:</h3>
+                    <div style='white-space: pre-line; font-size: 14px;'>{reflection_content}</div>
+                </div>
+                
+                <p style='margin-top: 30px;'>Best regards,<br>{getattr(self.email_exporter, 'student_name', 'Student')}</p>
+            </div>
+            """
             
             # Send email using the existing send_time_report method
             # We need to create a custom email with the reflection content
@@ -1609,6 +1617,72 @@ Student"""
         content += f"Total Hours: {total_hours:.1f}\n"
         return content
     
+    def generate_html_timesheet(self, entries):
+        """Generate HTML formatted timesheet for email"""
+        html = """
+        <h3 style='color: #2c3e50; margin-bottom: 15px;'>TIMESHEET SUMMARY:</h3>
+        <table border='1' cellpadding='8' cellspacing='0' style='border-collapse: collapse; width: 100%; font-family: Arial, sans-serif; font-size: 14px;'>
+        <thead>
+            <tr style='background-color: #34495e; color: white; font-weight: bold;'>
+                <th style='padding: 10px; text-align: left;'>Date</th>
+                <th style='padding: 10px; text-align: left;'>Project</th>
+                <th style='padding: 10px; text-align: left;'>Description</th>
+                <th style='padding: 10px; text-align: left;'>Time</th>
+                <th style='padding: 10px; text-align: left;'>Duration</th>
+            </tr>
+        </thead>
+        <tbody>
+        """
+        
+        total_hours = 0
+        for entry in entries:
+            entry_id, project_id, project_name, description, start_time, end_time, duration, rate, currency = entry
+            
+            # Format dates and times
+            start_dt = datetime.fromisoformat(start_time)
+            date_str = start_dt.strftime('%Y-%m-%d')
+            start_time_str = start_dt.strftime('%H:%M')
+            
+            if end_time:
+                end_dt = datetime.fromisoformat(end_time)
+                end_time_str = end_dt.strftime('%H:%M')
+            else:
+                end_time_str = "Running"
+            
+            # Format duration
+            if duration is not None:
+                hours = duration // 60
+                minutes = duration % 60
+                if hours > 0:
+                    duration_str = f"{hours}h {minutes}m"
+                else:
+                    duration_str = f"{minutes}m"
+                total_hours += duration / 60.0
+            else:
+                duration_str = "Running"
+            
+            html += f"""
+            <tr style='background-color: #f8f9fa; border-bottom: 1px solid #dee2e6;'>
+                <td style='padding: 10px; border-right: 1px solid #dee2e6;'>{date_str}</td>
+                <td style='padding: 10px; border-right: 1px solid #dee2e6; font-weight: bold; color: #2c3e50;'>{project_name}</td>
+                <td style='padding: 10px; border-right: 1px solid #dee2e6;'>{description or 'N/A'}</td>
+                <td style='padding: 10px; border-right: 1px solid #dee2e6;'>{start_time_str} - {end_time_str}</td>
+                <td style='padding: 10px; font-weight: bold; color: #27ae60;'>{duration_str}</td>
+            </tr>
+            """
+        
+        html += f"""
+        </tbody>
+        <tfoot>
+            <tr style='background-color: #3498db; color: white; font-weight: bold; font-size: 16px;'>
+                <td colspan='4' style='padding: 15px; text-align: right;'>Total Hours:</td>
+                <td style='padding: 15px; text-align: center; font-size: 18px;'>{total_hours:.1f}</td>
+            </tr>
+        </tfoot>
+        </table>
+        """
+        return html
+    
     def send_custom_email(self, recipients, subject, body, time_entries=None):
         """Send custom email with optional PDF attachment"""
         try:
@@ -1626,8 +1700,9 @@ Student"""
             msg['To'] = ', '.join(recipients)
             msg['Subject'] = subject
             
-            # Add body
-            msg.attach(MIMEText(body, 'plain'))
+            # Add body as HTML with proper content type
+            html_body = MIMEText(body, 'html', 'utf-8')
+            msg.attach(html_body)
             
             # Add PDF attachment if requested and entries provided
             if time_entries and self.include_pdf.get():
@@ -1745,9 +1820,39 @@ class EmailSettingsDialog:
         self.sender_email = tk.StringVar(value=self.email_exporter.sender_email or "")
         ttk.Entry(main_frame, textvariable=self.sender_email, width=40).grid(row=5, column=1, sticky=(tk.W, tk.E), pady=(0, 5))
         
-        ttk.Label(main_frame, text="Password/App Password:").grid(row=6, column=0, sticky=tk.W, pady=(0, 5))
+        # Password field with status indicator
+        password_label_text = "Password/App Password:"
+        if self.email_exporter.sender_password:
+            password_label_text += " (already configured)"
+        ttk.Label(main_frame, text=password_label_text).grid(row=6, column=0, sticky=tk.W, pady=(0, 5))
         self.sender_password = tk.StringVar()
-        ttk.Entry(main_frame, textvariable=self.sender_password, show="*", width=40).grid(row=6, column=1, sticky=(tk.W, tk.E), pady=(0, 5))
+        password_entry = ttk.Entry(main_frame, textvariable=self.sender_password, show="*", width=40)
+        password_entry.grid(row=6, column=1, sticky=(tk.W, tk.E), pady=(0, 5))
+        
+        # Add placeholder text if password is already stored
+        if self.email_exporter.sender_password:
+            password_entry.insert(0, "Leave blank to keep current password")
+            password_entry.configure(foreground="gray")
+            
+            def on_password_focus_in(event):
+                if password_entry.get() == "Leave blank to keep current password":
+                    password_entry.delete(0, tk.END)
+                    password_entry.configure(foreground="black")
+            
+            def on_password_focus_out(event):
+                if not password_entry.get():
+                    password_entry.insert(0, "Leave blank to keep current password")
+                    password_entry.configure(foreground="gray")
+            
+            password_entry.bind("<FocusIn>", on_password_focus_in)
+            password_entry.bind("<FocusOut>", on_password_focus_out)
+        
+        # Student Information
+        ttk.Label(main_frame, text="Student Information", font=("Arial", 12, "bold")).grid(row=7, column=0, columnspan=2, sticky=tk.W, pady=(20, 10))
+        
+        ttk.Label(main_frame, text="Student Name:").grid(row=8, column=0, sticky=tk.W, pady=(0, 5))
+        self.student_name = tk.StringVar(value=getattr(self.email_exporter, 'student_name', '') or "")
+        ttk.Entry(main_frame, textvariable=self.student_name, width=40).grid(row=8, column=1, sticky=(tk.W, tk.E), pady=(0, 5))
         
         # Help text
         help_text = """Common SMTP Settings:
@@ -1769,11 +1874,11 @@ OTHER PROVIDERS:
 
 Test your connection to verify settings work!"""
         
-        ttk.Label(main_frame, text=help_text, font=("Arial", 9), justify=tk.LEFT).grid(row=7, column=0, columnspan=2, sticky=tk.W, pady=(20, 0))
+        ttk.Label(main_frame, text=help_text, font=("Arial", 9), justify=tk.LEFT).grid(row=9, column=0, columnspan=2, sticky=tk.W, pady=(20, 0))
         
         # Buttons
         button_frame = ttk.Frame(main_frame)
-        button_frame.grid(row=8, column=0, columnspan=2, pady=(30, 20), sticky=(tk.W, tk.E))
+        button_frame.grid(row=10, column=0, columnspan=2, pady=(30, 20), sticky=(tk.W, tk.E))
         
         ttk.Button(button_frame, text="Test Connection", command=self.test_connection, width=15).pack(side=tk.LEFT, padx=(0, 10))
         ttk.Button(button_frame, text="Save Settings", command=self.save_settings, width=15).pack(side=tk.LEFT, padx=(0, 10))
@@ -1858,9 +1963,19 @@ Test your connection to verify settings work!"""
             smtp_port = int(self.smtp_port.get().strip())
             sender_email = self.sender_email.get().strip()
             sender_password = self.sender_password.get().strip()
+            student_name = self.student_name.get().strip()
             
-            if not all([smtp_server, sender_email, sender_password]):
-                messagebox.showerror("Error", "Please fill in all fields")
+            # Handle placeholder text
+            if sender_password == "Leave blank to keep current password":
+                sender_password = ""
+            
+            if not all([smtp_server, sender_email]):
+                messagebox.showerror("Error", "Please fill in SMTP server and email address")
+                return
+            
+            # Only require password if it's not already stored
+            if not sender_password and not self.email_exporter.sender_password:
+                messagebox.showerror("Error", "Please enter your password or app password")
                 return
             
             # Update email exporter settings
@@ -1869,7 +1984,12 @@ Test your connection to verify settings work!"""
             
             # Store credentials (password will be encrypted automatically)
             self.email_exporter.sender_email = sender_email
-            self.email_exporter.sender_password = sender_password
+            # Only update password if a new one is provided
+            if sender_password:
+                self.email_exporter.sender_password = sender_password
+            
+            # Store student name
+            self.email_exporter.student_name = student_name
             
             # Save to config file
             self.email_exporter.save_config()
